@@ -7,26 +7,23 @@ comb.f <- function(data, h, fcasts)
 {
   y <- combinef(fcasts, as.matrix(Scsr(data)), return="bottomlevelonly")
   colnames(y) <- colnames(data$y)
-  if(is.hts(data))
-    return(hts(y=y,g=data$g))
-  else
-    return(gts(y=y,g=data$g))
+  data$oldy <- data$y
+  data$y <- y
+  return(data)
 }
 
 # This version returns the full matrix of forecasts
 # fcasts = matrix of forecasts
 # S = summing matrix
 
-combinef <- function(fcasts, S, return=c("hts","gts","matrix","bottomlevelonly"))
+combinef <- function(fcasts, S, return=c("gts","matrix","bottomlevelonly"), hierarchical=FALSE)
 {
   return <- match.arg(return)
   y <- combinebf(fcasts, S)
-  if(return=="bottomlevelonly")
+  if(return == "bottomlevelonly")
     return(y)
-  else if(return=="hts")
-    return(hts(y,groupsfromS(S)))
-  else if(return=="gts")
-    return(gts(y,groupsfromS(S)))
+  else if(return == "gts")
+    return(gts(y,groupsfromS(S),hierarchical=hierarchical))
   else # return==matrix
   {
     ytilde <- y %*% t(S)
@@ -36,7 +33,6 @@ combinef <- function(fcasts, S, return=c("hts","gts","matrix","bottomlevelonly")
       ytilde <- ts(ytilde)
       tsp(ytilde) <- tsp(fcasts)
     }
-
     return(ytilde)
   }
 }
@@ -47,7 +43,7 @@ combinebf <- function(fcasts, S)
 {
   ytild <- as.matrix(t(qr.fitted(qr(S), t(fcasts))))
   bottom <- nrow(S)  - (ncol(S):1) + 1
-  y <- matrix(ytild[, bottom], nr = nrow(ytild))
+  y <- matrix(ytild[, bottom], nrow = nrow(ytild))
   if(is.ts(fcasts))
   {
     y <- ts(y)
